@@ -299,7 +299,7 @@ fn get_types(
                     }
                 }
                 _ => {
-                    let mut type_type: Option<Ident> = type_type.into();
+                    let type_type: Option<Ident> = type_type.into();
 
                     if let Some(typ) = type_type {
                         if let Some(p_type) = previous_type {
@@ -448,13 +448,21 @@ fn get_types(
                             };
                         }
                     }
-                    objects.push(quote! {
-                            #[derive(Deserialize,Serialize, Debug,Clone,PartialEq)]
-                            #[serde(rename_all = "camelCase")]
-                            pub struct #name {
-                                #(#object)*
-                            }
-                    });
+                    if object.len() > 0 {
+                        objects.push(quote! {
+                                #[derive(Deserialize,Serialize, Debug,Clone,PartialEq)]
+                                #[serde(rename_all = "camelCase")]
+                                pub struct #name {
+                                    #(#object)*
+                                }
+                        });
+                    } else {
+                        objects.push(quote! {
+                                #[derive(Deserialize,Serialize, Debug,Clone,PartialEq)]
+                                #[serde(rename_all = "camelCase")]
+                                pub struct #name(Option<serde_json::Value>);
+                        });
+                    }
                 }
                 TypeEnum::String => {
                     if let Some(enum_vec) = typ_element.type_enum.clone() {
@@ -546,7 +554,7 @@ fn get_types(
                     }
                 }
                 _ => {
-                    let mut type_type: Option<Ident> = type_type.into();
+                    let type_type: Option<Ident> = type_type.into();
 
                     if let Some(typ) = type_type {
                         if let Some(p_type) = previous_type {
@@ -764,7 +772,7 @@ pub fn get_commands(
                             }
                         }
                         _ => {
-                            let mut type_type: Option<Ident> = param_type.into();
+                            let type_type: Option<Ident> = param_type.into();
 
                             if let Some(typ) = type_type {
                                 if let Some(_) = return_type.optional {
@@ -1062,9 +1070,7 @@ pub fn get_parameters(
                         }
                     }
                     _ => {
-                        let mut type_type: Option<Ident> = param_type.into();
-
-                        let v = p_name.to_string();
+                        let type_type: Option<Ident> = param_type.into();
 
                         if let Some(typ) = type_type {
                             if let Some(_) = parameter.optional {
@@ -1158,7 +1164,7 @@ pub fn get_parameters(
         parameter_objects.push(quote! {
             #[derive(Deserialize,Serialize, Debug,Clone,PartialEq)]
             #[serde(rename_all = "camelCase")]
-            pub struct #name {}
+            pub struct #name(Option<serde_json::Value>);
         });
     }
 }
@@ -1360,9 +1366,7 @@ pub fn get_events(
                         }
                     }
                     _ => {
-                        let mut type_type: Option<Ident> = param_type.into();
-
-                        let v = p_name.to_string();
+                        let type_type: Option<Ident> = param_type.into();
 
                         if let Some(typ) = type_type {
                             if let Some(_) = parameter.optional {
@@ -1450,7 +1454,7 @@ pub fn get_events(
         event_objects.push(quote! {
             #[derive(Deserialize,Serialize, Debug,Clone,PartialEq)]
             #[serde(rename_all = "camelCase")]
-            pub struct #name {}
+            pub struct #name(Option<serde_json::Value>);
         });
     }
 }
